from setuptools import setup, find_packages
from setuptools.command.install import install
import os
import requests

class CustomInstallCommand(install):
    """Custom installation to download additional scripts."""
    def run(self):
        # Run the standard installation
        install.run(self)

        # Dynamically find where the package is installed
        package_name = "KEGGaNOG"  # Replace with your tool's actual package name
        script_dir = os.path.join(self.install_lib, package_name)

        # Ensure the directory exists
        if not os.path.exists(script_dir):
            raise FileNotFoundError(f"Package directory not found: {script_dir}")

        # Define the path for the script
        script_url = "https://raw.githubusercontent.com/bjtully/BioData/refs/heads/master/KEGGDecoder/KEGG_decoder.py"
        script_path = os.path.join(script_dir, "KEGG_decoder.py")

        # Download the script
        print(f"Downloading script from {script_url}...")
        response = requests.get(script_url)
        if response.status_code == 200:
            with open(script_path, "wb") as f:
                f.write(response.content)
            print(f"Script saved to {script_path}")
        else:
            print(f"Failed to download script. Status code: {response.status_code}")

with open("src/__init__.py") as f:
    exec(f.read())  # This will define __version__

setup(
    name="KEGGaNOG",
    version=__version__,
    description="A tool for generating KEGG heatmaps from eggnog-mapper outputs.",
    long_description=open("README_PyPI.md").read(),
    long_description_content_type="text/markdown",
    author="Ilia Popov",
    author_email="iljapopov17@gmail.com",
    url="https://github.com/iliapopov17/KEGGaNOG",
    packages=find_packages(),
    entry_points={
        "console_scripts": [
            "KEGGaNOG=src.kegganog:main",  # Maps the command to the main function
        ],
    },
    install_requires=open("requirements.txt").read().splitlines(),
    python_requires=">=3.6",
)